exports.up = function (knex) {
  return knex.schema
    .table('tenants', (t) => {
      // create temp columns
      t.text('cert_temp').nullable();
      t.text('decryptionPvk_temp').nullable();
      // Add callbackUrl column
      t.string('callbackUrl').nullable();
    })
    .then(() => {
      // set value of temp columns to value of existing deprecated
      return knex('tenants').update({
        cert_temp: knex.raw('??', ['cert']),
        decryptionPvk_temp: knex.raw('??', ['decryptionPvk']),
      });
    })
    .then(() => {
      // drop deprecated columns
      return knex.schema.table('tenants', (t) => {
        t.dropColumn('cert');
        t.dropColumn('decryptionPvk');
      });
    })
    .then(() => {
      // create columns with correct column_type
      return knex.schema.table('tenants', (t) => {
        t.text('cert').nullable();
        t.text('decryptionPvk').nullable();
      });
    })
    .then(() => {
      // set value of updated columns from temp columns
      return knex('tenants').update({
        cert: knex.raw('??', ['cert_temp']),
        decryptionPvk: knex.raw('??', ['decryptionPvk_temp']),
      });
    })
    .then(() => {
      // drop temp columns
      return knex.schema.table('tenants', (t) => {
        t.dropColumn('cert_temp');
        t.dropColumn('decryptionPvk_temp');
      });
    })
    .then(() => {
      // *NOTE: THIS IS HACKY AND STINKS*
      // knex fails to copy over the unique constraint when migrating table over
      // to temp table making the remove column alterations above
      return knex.schema.table('tenants', (t) => {
        if (t.client.config.client === 'sqlite3') {
          t.unique(['hostname']);
        }
      });
    });
};

exports.down = function (knex, Promise) {};
