const { service } = require('./service-layer');

// returns a coronerdUrl string if exists
function fuzzyGetAuthenticatedCoronerd(url) {
  const key = Object.keys(
    service.identityManager.authenticated
  ).filter((coronerdUrl) => coronerdUrl.includes(url))[0];
  return key;
}

// Refresh cache every 10 minutes
function shouldAuthenticateCoronerd(url) {
  return (
    !(
      service.identityManager.authenticated[url] &&
      service.identityManager.authenticated[url]._config
    ) ||
    (service.identityManager.authenticated[url] &&
      Date.now() - service.identityManager.authenticated[url].timestamp >
        600000)
  );
}

function rehydtrateToken(url) {
  return service.identityManager
    .loginCoronerd(url)
    .then((config) => {
      service.identityManager.authenticated[url] = {
        _config: config,
        timestamp: Date.now(),
      };
      return config || {};
    })
    .catch((error) => {
      throw error;
    });
}

// only requests a new authenticed config if one does not already exist
function authenticateCoronerd(url) {
  if (!shouldAuthenticateCoronerd(url)) {
    return undefined;
  }

  rehydtrateToken(url)
    .then((_config) => service._logger.info(`authenticatedCoronerd: ${url}`))
    .catch(service._logger.error);
}

function invalidateAuthenticatedCoronerd(url) {
  const coronerdUrl = fuzzyGetAuthenticatedCoronerd(url);
  service.identityManager.authenticated[coronerdUrl] = {};
}

module.exports = {
  rehydtrateToken,
  authenticateCoronerd,
  fuzzyGetAuthenticatedCoronerd,
  invalidateAuthenticatedCoronerd,
};
